Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(220)

Unified Diff: webrtc/modules/audio_processing/logging/apm_data_dumper.cc

Issue 2300813004: Moved the place for the aec_debug_dump build flag and changed the name to apm_debug_dump (Closed)
Patch Set: Removed duplicate definition of build flag Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/modules/audio_processing/logging/apm_data_dumper.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/modules/audio_processing/logging/apm_data_dumper.cc
diff --git a/webrtc/modules/audio_processing/logging/apm_data_dumper.cc b/webrtc/modules/audio_processing/logging/apm_data_dumper.cc
index 3202006d3c5e498413768d4d2a31069f2808d921..66ec5178d0b5a067875241bea8c5a526966d6a7b 100644
--- a/webrtc/modules/audio_processing/logging/apm_data_dumper.cc
+++ b/webrtc/modules/audio_processing/logging/apm_data_dumper.cc
@@ -15,16 +15,16 @@
#include "webrtc/base/stringutils.h"
// Check to verify that the define is properly set.
-#if !defined(WEBRTC_AEC_DEBUG_DUMP) || \
- (WEBRTC_AEC_DEBUG_DUMP != 0 && WEBRTC_AEC_DEBUG_DUMP != 1)
-#error "Set WEBRTC_AEC_DEBUG_DUMP to either 0 or 1"
+#if !defined(WEBRTC_APM_DEBUG_DUMP) || \
+ (WEBRTC_APM_DEBUG_DUMP != 0 && WEBRTC_APM_DEBUG_DUMP != 1)
+#error "Set WEBRTC_APM_DEBUG_DUMP to either 0 or 1"
#endif
namespace webrtc {
namespace {
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
std::string FormFileName(const char* name,
int instance_index,
int reinit_index,
@@ -37,7 +37,7 @@ std::string FormFileName(const char* name,
} // namespace
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
ApmDataDumper::ApmDataDumper(int instance_index)
: instance_index_(instance_index) {}
#else
@@ -46,7 +46,7 @@ ApmDataDumper::ApmDataDumper(int instance_index) {}
ApmDataDumper::~ApmDataDumper() {}
-#if WEBRTC_AEC_DEBUG_DUMP == 1
+#if WEBRTC_APM_DEBUG_DUMP == 1
FILE* ApmDataDumper::GetRawFile(const char* name) {
std::string filename =
FormFileName(name, instance_index_, recording_set_index_, ".dat");
« no previous file with comments | « webrtc/modules/audio_processing/logging/apm_data_dumper.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698